@@ -306,6 +306,7 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 		{
 			m_embeddedProfile = profArray;
 			m_imageInfoRecord.profileName = prof.productDescription();
+			m_imageInfoRecord.embeddedProfileName = m_imageInfoRecord.profileName;
 		}
 		m_imageInfoRecord.isEmbedded = profileIsValid;
 		free(EmbedBuffer);
@@ -313,7 +314,7 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 	else
 	{
 		m_imageInfoRecord.isEmbedded = false;
-		m_imageInfoRecord.profileName = "";
+		m_imageInfoRecord.profileName.clear();
 	}
 
 	unsigned int PhotoshopLen = 0;
@@ -335,7 +336,7 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 		else if (cinfo.output_components == 1)
 			m_imageInfoRecord.colorspace = ColorSpaceGray;
 		m_imageInfoRecord.progressive = jpeg_has_multiple_scans(&cinfo);
-		parseRessourceData(strPhot, fakeHeader, PhotoshopLen);
+		parseResourceData(strPhot, fakeHeader, PhotoshopLen);
 		// Photoshop resolution is more accurate than jpeg header resolution
 		xres = m_imageInfoRecord.xres;
 		yres = m_imageInfoRecord.yres;
@@ -402,8 +403,8 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 	{
 		m_image = QImage( cinfo.output_width, cinfo.output_height, QImage::Format_Indexed8 );
 		m_image.setColorCount(256);
-		for (int i=0; i<256; i++)
-			m_image.setColor(i, qRgb(i,i,i));
+		for (int i = 0; i < 256; i++)
+			m_image.setColor(i, qRgb(i, i, i));
 	}
 	if (!m_image.isNull())
 	{
@@ -499,11 +500,11 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 			m_image = QImage( cinfo.output_width, cinfo.output_height, QImage::Format_ARGB32 );
 			QRgb *s;
 			QRgb *d;
-			for (int yi=0; yi < tmpImg.height(); ++yi)
+			for (int yi = 0; yi < tmpImg.height(); ++yi)
 			{
 				s = (QRgb*)(tmpImg.scanLine( yi ));
 				d = (QRgb*)(m_image.scanLine( yi ));
-				for (int xi=0; xi < tmpImg.width(); ++xi)
+				for (int xi = 0; xi < tmpImg.width(); ++xi)
 				{
 					(*d) = (*s);
 					s++;
@@ -531,11 +532,13 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 					break;
 				case 4:
 					M = flip;
+					/* fall through */
 				case 3:
 					M.rotate (180);
 					break;
 				case 5:
 					M = flip;
+					/* fall through */
 				case 6:
 					M.rotate(90);
 					oxres = m_imageInfoRecord.xres;
@@ -545,6 +548,7 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 					break;
 				case 7:
 					M = flip;
+					/* fall through */
 				case 8:
 					M.rotate(270);
 					oxres = m_imageInfoRecord.xres;
@@ -552,7 +556,8 @@ bool ScImgDataLoader_JPEG::loadPicture(const QString& fn, int /*page*/, int res,
 					m_imageInfoRecord.xres = oyres;
 					m_imageInfoRecord.yres = oxres;
 					break;
-				default: break; // should never happen
+				default:
+					break; // should never happen
 			}
 			m_image = m_image.transformed(M);
 		}
